****************************
* File: provincialtreasury.do 
* Questionnaire type: Provincial Treasury Questionnaire
* Country: Cambodia
*****************************

version 10.0
cd "Source/Cambodia 2004 P E/Data/4.1. Data"
capture clear
capture log close
clear
set mem 700m
set more off
use "provincialtreasury.dta"


**************************************************
*** Adding value labels
***************************************************
label drop _all

label define s1_q2_pr 1 `"Bantey meanchey"', modify
label define s1_q2_pr 2 `"Kanpong Cham"', modify
label define s1_q2_pr 3 `"Kampong Chhnang"', modify
label define s1_q2_pr 4 `"Kampot"', modify
label define s1_q2_pr 5 `"Kratie"', modify
label define s1_q2_pr 6 `"Preah Vihear"', modify
label define s1_q2_pr 7 `"Prey Veng"', modify
label define s1_q2_pr 8 `"Sihanoukville"', modify
label define s3_ch1_l 1 `"yes"', modify
label define s3_ch1_l 2 `"No"', modify
label define s3_ch1_m 1 `"annually"', modify
label define s3_ch1_m 2 `"monthly"', modify
label define s3_ch_af 1 `"Yes"', modify
label define s3_ch_af 2 `"No"', modify
label define s3_ch_ag 1 `"annually"', modify
label define s3_ch_ag 2 `"monthly"', modify
label define s3_ch_ao 1 `"Yes"', modify
label define s3_ch_ao 2 `"No"', modify
label define s3_ch_ap 1 `"annually"', modify
label define s3_ch_ap 2 `"monthly"', modify
label define s3_ch_bw 1 `"food for patients in hospital"', modify
label define s3_ch_bw 2 `"electricity for offices"', modify
label define s3_ch_bw 3 `"rent/other expenses for the governor's offices"', modify
label define s3_ch_bw 4 `"other (please specify)"', modify
label define s3_ch_bw 9 `"not applicable"', modify
label define s3_ch_bx 1 `"food for patients in hospital"', modify
label define s3_ch_bx 2 `"electricity for offices"', modify
label define s3_ch_bx 3 `"rent/other expenses for the governor's offices"', modify
label define s3_ch_bx 4 `"other (please specify)"', modify
label define s3_ch_bx 9 `"not applicable"', modify
label define s3_ch_by 1 `"food for patients in hospital"', modify
label define s3_ch_by 2 `"electricity for offices"', modify
label define s3_ch_by 3 `"rent/other expenses for the governor's offices"', modify
label define s3_ch_by 4 `"other (please specify)"', modify
label define s3_ch_by 9 `"not applicable"', modify


**************************************************
*** Ensure unique id
***************************************************

gen uid = _n

**************************************************
*** Recode missing values
***************************************************

*    DECODE MISSING VALUES
# d ;
qui mvdecode _all, mv(
999999999=.l\99999999=.l\9999999=.l\999999=.l\99999=.l\9999=.l\999=.l\99=.l\
888888888=.d\88888888=.d\8888888=.d\888888=.d\88888=.d\8888=.d\888=.d\88=.d \
777777777=.n\77777777=.n\7777777=.n\777777=.n\77777=.n\7777=.n\777=.n\77=.n \
666666666=.r\66666666=.r\6666666=.r\666666=.r\66666=.r\6666=.r\666=.r\66=.r);

qui mvdecode _all, mv(
99999.9=.l\9999.9=.l\999.9=.l\99.9=.l\
88888.8=.d\8888.8=.d\888.8=.d\88.8=.d \
77777.7=.n\7777.7=.n\777.7=.n\77.7=.n \
66666.6=.r\6666.6=.r\666.6=.r\66.6=.r);

qui mvdecode  s4_q4b	s4_q4a	s3_ch_by	s3_ch_bx	s3_ch_bw	s3_ch_bv	s3_ch_bu	s3_ch_bt	s3_ch_bs	s3_ch_br	s3_ch_bq	s3_ch_bp	s3_ch_bo	s3_ch_bn	s3_ch_bm	s3_ch_bl	s3_ch_bk	s3_ch_bj	s3_ch_bi	s3_ch_bh	s3_ch_bg	s3_ch_bf	s3_ch_be	s3_ch_bd	s3_ch_bc	s3_ch_bb	s3_ch_ba	s3_ch_az	s3_ch_ay	s3_ch_ax	s3_ch_aw	s3_ch_av	s3_ch_au	s3_ch_at	s3_ch_as	s3_ch_ar	s3_ch_aq	s3_qg30	s3_qg29	s3_qg28	s3_qg27	s3_qg26	s3_qg25	s3_qf30	s3_qf29	s3_qf28	s3_qf27	s3_qf26	s3_qf25	s3_qe30	s3_qe29	s3_qe28	s3_qe27	s3_qe26	s3_qe25	s3_qd30	s3_qd29	s3_qd28	s3_qd27	s3_qd26	s3_qd25	s3_qc30	s3_qc29 s3_qc28 s3_qc27 s3_qc26 s3_qc25 s3_qb30 s3_qb29 s3_qb28 s3_qb27 s3_qb26 s3_qb25 s3_qa30 s3_qa29 s3_qa28 s3_qa27 s3_qa26 s3_qa25 s3_q24_r s3_q24_q s3_q24_p s3_q24_o s3_q24_n s3_q24_m s3_ch_ap s3_ch_ao s3_ch_an s3_ch_am s3_ch_al s3_ch_ak s3_ch_aj s3_ch_ai s3_ch_ah s3_ql20 s3_ql19 s3_ql18 s3_ql17 s3_ql16 s3_ql15 s3_qk20 s3_qk19 s3_qk18 s3_qk17 s3_qk16 s3_qk15 s3_qj20 s3_qj19 s3_qj18 s3_qj17 s3_qj16 s3_qj15 s3_qi20 s3_qi19 s3_qi18 s3_qi17 s3_qi16 s3_qi15 s3_qh20 s3_qh19 s3_qh18 s3_qh17 s3_qh16 s3_qh15 s3_qg20 s3_qg19 s3_qg18 s3_qg17 s3_qg16 s3_qg15 s3_qf20 s3_qf19 s3_qf18 s3_qf17 s3_qf16 s3_qf15 s3_qe20 s3_qe19 s3_qe18 s3_qe17 s3_qe16 s3_qe15 s3_qd20 s3_qd19 s3_qd18 s3_qd17 s3_qd16 s3_qd15 s3_qc20 s3_qc19 s3_qc18 s3_qc17 s3_qc16 s3_qc15 s3_qb20 s3_qb19 s3_qb18 s3_qb17 s3_qb16 s3_qb15 s3_qa20 s3_qa19 s3_qa18 s3_qa17 s3_qa16 s3_qa15 s3_q14_l s3_q14_k s3_q14_j s3_q14_i s3_q14_h s3_q14_g s3_ch_ag s3_ch_af s3_ch_ae s3_ch_ad s3_ch_ac s3_ch_ab s3_ch_aa s3_ch1_z s3_ch1_y s3_ch1_x s3_ch1_w s3_ch1_v s3_ch1_u s3_ch1_t s3_ql10 s3_ql9_c s3_ql8_c s3_ql7_c s3_ql6_c s3_ql5_c s3_qk10 s3_qk9_c s3_qk8_c s3_qk7_c s3_qk6_c s3_qk5_c s3_qj10 s3_qj9_c s3_qj8_c s3_qj7_c s3_qj6_c s3_qj5_c s3_qi10 s3_qi9_c s3_qi8_c s3_qi7_c s3_qi6_c s3_qi5_c s3_qh10 s3_qh9_c s3_qh8_c s3_qh7_c s3_qh6_c s3_qh5_c s3_qg10 s3_qg9_c s3_qg8_c s3_qg7_c s3_qg6_c s3_qg5_c s3_qf10 s3_qf9_c s3_qf8_c s3_qf7_c s3_qf6_c s3_qf5_c s3_qe10 s3_qe9_c s3_qe8_c s3_qe7_c s3_qe6_c s3_qe5_c s3_qd10 s3_qd9_c s3_qd8_c s3_qd7_c s3_qd6_c s3_qd5_c s3_qc10 s3_qc9_c s3_qc8_c s3_qc7_c s3_qc6_c s3_qc5_c s3_qb10 s3_qb9_c s3_qb8_c s3_qb7_c s3_qb6_c s3_qb5_c s3_qa10 s3_qa9_c s3_qa8_c s3_qa7_c s3_qa6_c s3_qa5_c s3_ch1_s s3_ch1_r s3_ch1_q s3_ch1_p s3_ch1_o s3_ch1_n s3_ch1_m s3_ch1_l s3_ch1_k s3_ch1_j s3_ch1_i s3_ch1_h s3_ch1_g s3_ch1_f s3_ch1_e s3_ch1_d s3_ch1_c s3_ch1_b s3_ch1_a s3_ch11 s2_ch_cs s2_ch_cr s2_ch_cq s2_ch_cp s2_ch_co s2_ch_cn s2_ch_cm s2_ch_cl s2_ch_ck s2_ch_cj s2_ch_ci s2_ch_ch s2_ch_cg s2_ch_cf s2_ch_ce s2_ch_cd s2_ch_cc s2_ch_cb s2_ch_ca s2_ch_bz s2_ch_by s2_ch_bx s2_ch_bw s2_ch_bv s2_ch_bu s2_ch_bt s2_ch_bs s2_ch_br s2_ch_bq s2_ch_bp s2_ch_bo s2_ch_bn s2_ch_bm s2_ch_bl s2_ch_bk s2_ch_bj s2_ch_bi s2_ch_bh s2_ch_bg s2_ch_bf s2_ch_be s2_ch_bd s2_ch_bc s2_ch_bb s2_ch_ba s2_ch_az s2_ch_ay s2_ch_ax s2_ch_aw s2_ch_av s2_ch_au s2_ch_at s2_ch_as s2_ch_ar s2_ch_aq s2_ch_ap s2_ch_ao s2_ch_an s2_ch_am s2_ch_al s2_ch_ak s2_ch_aj s2_ch_ai s2_ch_ah s2_ch_ag s2_ch_af s2_ch_ae s2_ch_ad s2_ch_ac s2_ch_ab s2_ch_aa s2_ch1_z s2_ch1_y s2_ch1_x s2_ch1_w s2_ch1_v s2_ch1_u s2_ch1_t s2_ch1_s s2_ch1_r s2_ch1_q s2_ch1_p s2_ch1_o s2_ch1_n s2_ch1_m s2_ch1_l s2_ch1_k s2_ch1_j s2_ch1_i s2_ch1_h s2_ch1_g s2_ch1_f s2_ch1_e s2_ch1_d s2_ch1_c s2_ch1_b s2_ch1_a s2_ch13, mv(
9=.l\
8=.d \
7=.n \
6=.r);

# d cr;


* Encode missing STATA values back to missing value codes, in case data users want to convert file to other statistical software.
quietly mvencode _all,mv (.d = -666 \ .n = -777 \ .l = -888 \ .r = -999)

**************************************************
***  Identify outliers
**************************************************

mvdecode   s1_q1_sa  s2_ch_aq  s2_ch_cn  s3_qd10   s3_ch1_t  s3_qe20   s3_ch_an  s3_qg29 s1_q2_pr  s2_ch_ar  s2_ch_co  s3_qe5_c  s3_ch1_u  s3_qf15   s3_ch_ao  s3_qg30 s1_q3_da  s2_ch_as  s2_ch_cp  s3_qe6_c  s3_ch1_v  s3_qf16   s3_ch_ap  s3_ch_aq s1_q4_st  s2_ch_at  s2_ch_cq  s3_qe7_c  s3_ch1_w  s3_qf17   s3_q24_m  s3_ch_ar s2_ch_au  s2_ch_cr  s3_qe8_c  s3_ch1_x  s3_qf18   s3_q24_n  s3_ch_as date_of   s2_ch_av  s2_ch_cs  s3_qe9_c  s3_ch1_y  s3_qf19   s3_q24_o  s3_ch_at s2_ch13   s2_ch_aw  s3_ch11   s3_qe10   s3_ch1_z  s3_qf20   s3_q24_p  s3_ch_au s2_ch1_a  s2_ch_ax  s3_ch1_a  s3_qf5_c  s3_ch_aa  s3_qg15   s3_q24_q  s3_ch_av s2_ch1_b  s2_ch_ay  s3_ch1_b  s3_qf6_c  s3_ch_ab  s3_qg16   s3_q24_r  s3_ch_aw s2_ch1_c  s2_ch_az  s3_ch1_c  s3_qf7_c  s3_ch_ac  s3_qg17   s3_qa25   s3_ch_ax s2_ch1_d  s2_ch_ba  s3_ch1_d  s3_qf8_c  s3_ch_ad  s3_qg18   s3_qa26   s3_ch_ay s2_ch1_e  s2_ch_bb  s3_ch1_e  s3_qf9_c  s3_ch_ae  s3_qg19   s3_qa27   s3_ch_az s2_ch1_f  s2_ch_bc  s3_ch1_f  s3_qf10   s3_ch_af  s3_qg20   s3_qa28   s3_ch_ba s2_ch1_g  s2_ch_bd  s3_ch1_g  s3_qg5_c  s3_ch_ag  s3_qh15   s3_qa29   s3_ch_bb s2_ch1_h  s2_ch_be  s3_ch1_h  s3_qg6_c  s3_q14_g  s3_qh16   s3_qa30   s3_ch_bc s2_ch1_i  s2_ch_bf  s3_ch1_i  s3_qg7_c  s3_q14_h  s3_qh17   s3_qb25   s3_ch_bd s2_ch1_j  s2_ch_bg  s3_ch1_j  s3_qg8_c  s3_q14_i  s3_qh18   s3_qb26   s3_ch_be s2_ch1_k  s2_ch_bh  s3_ch1_k  s3_qg9_c  s3_q14_j  s3_qh19   s3_qb27   s3_ch_bf s2_ch1_l  s2_ch_bi  s3_ch1_l  s3_qg10   s3_q14_k  s3_qh20   s3_qb28   s3_ch_bg s2_ch1_m  s2_ch_bj  s3_ch1_m  s3_qh5_c  s3_q14_l  s3_qi15   s3_qb29   s3_ch_bh s2_ch1_n  s2_ch_bk  s3_ch1_n  s3_qh6_c  s3_qa15   s3_qi16   s3_qb30   s3_ch_bi s2_ch1_o  s2_ch_bl  s3_ch1_o  s3_qh7_c  s3_qa16   s3_qi17   s3_qc25   s3_ch_bj s2_ch1_p  s2_ch_bm  s3_ch1_p  s3_qh8_c  s3_qa17   s3_qi18   s3_qc26   s3_ch_bk s2_ch1_q  s2_ch_bn  s3_ch1_q  s3_qh9_c  s3_qa18   s3_qi19   s3_qc27   s3_ch_bl s2_ch1_r  s2_ch_bo  s3_ch1_r  s3_qh10   s3_qa19   s3_qi20   s3_qc28   s3_ch_bm s2_ch1_s  s2_ch_bp  s3_ch1_s  s3_qi5_c  s3_qa20   s3_qj15   s3_qc29   s3_ch_bn s2_ch1_t  s2_ch_bq  s3_qa5_c  s3_qi6_c  s3_qb15   s3_qj16   s3_qc30   s3_ch_bo s2_ch1_u  s2_ch_br  s3_qa6_c  s3_qi7_c  s3_qb16   s3_qj17   s3_qd25   s3_ch_bp s2_ch1_v  s2_ch_bs  s3_qa7_c  s3_qi8_c  s3_qb17   s3_qj18   s3_qd26   s3_ch_bq s2_ch1_w  s2_ch_bt  s3_qa8_c  s3_qi9_c  s3_qb18   s3_qj19   s3_qd27   s3_ch_br s2_ch1_x  s2_ch_bu  s3_qa9_c  s3_qi10   s3_qb19   s3_qj20   s3_qd28   s3_ch_bs s2_ch1_y  s2_ch_bv  s3_qa10   s3_qj5_c  s3_qb20   s3_qk15   s3_qd29   s3_ch_bt s2_ch1_z  s2_ch_bw  s3_qb5_c  s3_qj6_c  s3_qc15   s3_qk16   s3_qd30   s3_ch_bu s2_ch_aa  s2_ch_bx  s3_qb6_c  s3_qj7_c  s3_qc16   s3_qk17   s3_qe25   s3_ch_bv s2_ch_ab  s2_ch_by  s3_qb7_c  s3_qj8_c  s3_qc17   s3_qk18   s3_qe26   s3_ch_bw s2_ch_ac  s2_ch_bz  s3_qb8_c  s3_qj9_c  s3_qc18   s3_qk19   s3_qe27   s3_ch_bx s2_ch_ad  s2_ch_ca  s3_qb9_c  s3_qj10   s3_qc19   s3_qk20   s3_qe28   s3_ch_by s2_ch_ae  s2_ch_cb  s3_qb10   s3_qk5_c  s3_qc20   s3_ql15   s3_qe29   s4_q1_na s2_ch_af  s2_ch_cc  s3_qc5_c  s3_qk6_c  s3_qd15   s3_ql16   s3_qe30   s4_q1__a s2_ch_ag  s2_ch_cd  s3_qc6_c  s3_qk7_c  s3_qd16   s3_ql17   s3_qf25   s4_q2_ti s2_ch_ah  s2_ch_ce  s3_qc7_c  s3_qk8_c  s3_qd17   s3_ql18   s3_qf26   s4_q3_nu s2_ch_ai  s2_ch_cf  s3_qc8_c  s3_qk9_c  s3_qd18   s3_ql19   s3_qf27   s4_q4a s2_ch_aj  s2_ch_cg  s3_qc9_c  s3_qk10   s3_qd19   s3_ql20   s3_qf28   s4_q4b s2_ch_ak  s2_ch_ch  s3_qc10   s3_ql5_c  s3_qd20   s3_ch_ah  s3_qf29   s4_q5_na s2_ch_al  s2_ch_ci  s3_qd5_c  s3_ql6_c  s3_qe15   s3_ch_ai  s3_qf30    s2_ch_am  s2_ch_cj  s3_qd6_c  s3_ql7_c  s3_qe16   s3_ch_aj  s3_qg25   uid s2_ch_an  s2_ch_ck  s3_qd7_c  s3_ql8_c  s3_qe17   s3_ch_ak  s3_qg26 s2_ch_ao  s2_ch_cl  s3_qd8_c  s3_ql9_c  s3_qe18   s3_ch_al  s3_qg27 s2_ch_ap  s2_ch_cm  s3_qd9_c  s3_ql10   s3_qe19   s3_ch_am  s3_qg28, mv(0 = .z)
grubbs  s2_ch_aq  s2_ch_cn  s3_qd10   s3_ch1_t  s3_qe20   s3_ch_an  s3_qg29 s1_q2_pr  s2_ch_ar  s2_ch_co  s3_qe5_c  s3_ch1_u  s3_qf15   s3_ch_ao  s3_qg30 s1_q3_da  s2_ch_as  s2_ch_cp  s3_qe6_c  s3_ch1_v  s3_qf16   s3_ch_ap  s3_ch_aq  s2_ch_at  s2_ch_cq  s3_qe7_c  s3_ch1_w  s3_qf17   s3_q24_m  s3_ch_ar s2_ch_au  s2_ch_cr  s3_qe8_c  s3_ch1_x  s3_qf18   s3_q24_n  s3_ch_as date_of   s2_ch_av  s2_ch_cs  s3_qe9_c  s3_ch1_y  s3_qf19   s3_q24_o  s3_ch_at s2_ch13   s2_ch_aw  s3_ch11   s3_qe10   s3_ch1_z  s3_qf20   s3_q24_p  s3_ch_au s2_ch1_a  s2_ch_ax  s3_ch1_a  s3_qf5_c  s3_ch_aa  s3_qg15   s3_q24_q  s3_ch_av s2_ch1_b  s2_ch_ay  s3_ch1_b  s3_qf6_c  s3_ch_ab  s3_qg16   s3_q24_r  s3_ch_aw s2_ch1_c  s2_ch_az  s3_ch1_c  s3_qf7_c  s3_ch_ac  s3_qg17   s3_qa25   s3_ch_ax s2_ch1_d  s2_ch_ba  s3_ch1_d  s3_qf8_c  s3_ch_ad  s3_qg18   s3_qa26   s3_ch_ay s2_ch1_e  s2_ch_bb  s3_ch1_e  s3_qf9_c  s3_ch_ae  s3_qg19   s3_qa27   s3_ch_az s2_ch1_f  s2_ch_bc  s3_ch1_f  s3_qf10   s3_ch_af  s3_qg20   s3_qa28   s3_ch_ba s2_ch1_g  s2_ch_bd  s3_ch1_g  s3_qg5_c  s3_ch_ag  s3_qh15   s3_qa29   s3_ch_bb s2_ch1_h  s2_ch_be  s3_ch1_h  s3_qg6_c  s3_q14_g  s3_qh16   s3_qa30   s3_ch_bc s2_ch1_i  s2_ch_bf  s3_ch1_i  s3_qg7_c  s3_q14_h  s3_qh17   s3_qb25   s3_ch_bd s2_ch1_j  s2_ch_bg  s3_ch1_j  s3_qg8_c  s3_q14_i  s3_qh18   s3_qb26   s3_ch_be s2_ch1_k  s2_ch_bh  s3_ch1_k  s3_qg9_c  s3_q14_j  s3_qh19   s3_qb27   s3_ch_bf s2_ch1_l  s2_ch_bi  s3_ch1_l  s3_qg10   s3_q14_k  s3_qh20   s3_qb28   s3_ch_bg s2_ch1_m  s2_ch_bj  s3_ch1_m  s3_qh5_c  s3_q14_l  s3_qi15   s3_qb29   s3_ch_bh s2_ch1_n  s2_ch_bk  s3_ch1_n  s3_qh6_c  s3_qa15   s3_qi16   s3_qb30   s3_ch_bi s2_ch1_o  s2_ch_bl  s3_ch1_o  s3_qh7_c  s3_qa16   s3_qi17   s3_qc25   s3_ch_bj s2_ch1_p  s2_ch_bm  s3_ch1_p  s3_qh8_c  s3_qa17   s3_qi18   s3_qc26   s3_ch_bk s2_ch1_q  s2_ch_bn  s3_ch1_q  s3_qh9_c  s3_qa18   s3_qi19   s3_qc27   s3_ch_bl s2_ch1_r  s2_ch_bo  s3_ch1_r  s3_qh10   s3_qa19   s3_qi20   s3_qc28   s3_ch_bm s2_ch1_s  s2_ch_bp  s3_ch1_s  s3_qi5_c  s3_qa20   s3_qj15   s3_qc29   s3_ch_bn s2_ch1_t  s2_ch_bq  s3_qa5_c  s3_qi6_c  s3_qb15   s3_qj16   s3_qc30   s3_ch_bo s2_ch1_u  s2_ch_br  s3_qa6_c  s3_qi7_c  s3_qb16   s3_qj17   s3_qd25   s3_ch_bp s2_ch1_v  s2_ch_bs  s3_qa7_c  s3_qi8_c  s3_qb17   s3_qj18   s3_qd26   s3_ch_bq s2_ch1_w  s2_ch_bt  s3_qa8_c  s3_qi9_c  s3_qb18   s3_qj19   s3_qd27   s3_ch_br s2_ch1_x  s2_ch_bu  s3_qa9_c  s3_qi10   s3_qb19   s3_qj20   s3_qd28   s3_ch_bs s2_ch1_y  s2_ch_bv  s3_qa10   s3_qj5_c  s3_qb20   s3_qk15   s3_qd29   s3_ch_bt s2_ch1_z  s2_ch_bw  s3_qb5_c  s3_qj6_c  s3_qc15   s3_qk16   s3_qd30   s3_ch_bu s2_ch_aa  s2_ch_bx  s3_qb6_c  s3_qj7_c  s3_qc16   s3_qk17   s3_qe25   s3_ch_bv s2_ch_ab  s2_ch_by  s3_qb7_c  s3_qj8_c  s3_qc17   s3_qk18   s3_qe26   s3_ch_bw s2_ch_ac  s2_ch_bz  s3_qb8_c  s3_qj9_c  s3_qc18   s3_qk19   s3_qe27   s3_ch_bx s2_ch_ad  s2_ch_ca  s3_qb9_c  s3_qj10   s3_qc19   s3_qk20   s3_qe28   s3_ch_by s2_ch_ae  s2_ch_cb  s3_qb10   s3_qk5_c  s3_qc20   s3_ql15   s3_qe29   s2_ch_af  s2_ch_cc  s3_qc5_c  s3_qk6_c  s3_qd15   s3_ql16   s3_qe30   s2_ch_ag  s2_ch_cd  s3_qc6_c  s3_qk7_c  s3_qd16   s3_ql17   s3_qf25   s2_ch_ah  s2_ch_ce  s3_qc7_c  s3_qk8_c  s3_qd17   s3_ql18   s3_qf26   s4_q3_nu s2_ch_ai  s2_ch_cf  s3_qc8_c  s3_qk9_c  s3_qd18   s3_ql19   s3_qf27   s4_q4a s2_ch_aj  s2_ch_cg  s3_qc9_c  s3_qk10   s3_qd19   s3_ql20   s3_qf28   s4_q4b s2_ch_ak  s2_ch_ch  s3_qc10   s3_ql5_c  s3_qd20   s3_ch_ah  s3_qf29   s2_ch_al  s2_ch_ci  s3_qd5_c  s3_ql6_c  s3_qe15   s3_ch_ai  s3_qf30   s2_ch_am  s2_ch_cj  s3_qd6_c  s3_ql7_c  s3_qe16   s3_ch_aj  s3_qg25   uid s2_ch_an  s2_ch_ck  s3_qd7_c  s3_ql8_c  s3_qe17   s3_ch_ak  s3_qg26 s2_ch_ao  s2_ch_cl  s3_qd8_c  s3_ql9_c  s3_qe18   s3_ch_al  s3_qg27 s2_ch_ap  s2_ch_cm  s3_qd9_c  s3_ql10   s3_qe19   s3_ch_am  s3_qg28, level(99.99)
mvencode  s1_q1_sa  s2_ch_aq  s2_ch_cn  s3_qd10   s3_ch1_t  s3_qe20   s3_ch_an  s3_qg29 s1_q2_pr  s2_ch_ar  s2_ch_co  s3_qe5_c  s3_ch1_u  s3_qf15   s3_ch_ao  s3_qg30 s1_q3_da  s2_ch_as  s2_ch_cp  s3_qe6_c  s3_ch1_v  s3_qf16   s3_ch_ap  s3_ch_aq s1_q4_st  s2_ch_at  s2_ch_cq  s3_qe7_c  s3_ch1_w  s3_qf17   s3_q24_m  s3_ch_ar   s2_ch_au  s2_ch_cr  s3_qe8_c  s3_ch1_x  s3_qf18   s3_q24_n  s3_ch_as date_of   s2_ch_av  s2_ch_cs  s3_qe9_c  s3_ch1_y  s3_qf19   s3_q24_o  s3_ch_at s2_ch13   s2_ch_aw  s3_ch11   s3_qe10   s3_ch1_z  s3_qf20   s3_q24_p  s3_ch_au s2_ch1_a  s2_ch_ax  s3_ch1_a  s3_qf5_c  s3_ch_aa  s3_qg15   s3_q24_q  s3_ch_av s2_ch1_b  s2_ch_ay  s3_ch1_b  s3_qf6_c  s3_ch_ab  s3_qg16   s3_q24_r  s3_ch_aw s2_ch1_c  s2_ch_az  s3_ch1_c  s3_qf7_c  s3_ch_ac  s3_qg17   s3_qa25   s3_ch_ax s2_ch1_d  s2_ch_ba  s3_ch1_d  s3_qf8_c  s3_ch_ad  s3_qg18   s3_qa26   s3_ch_ay s2_ch1_e  s2_ch_bb  s3_ch1_e  s3_qf9_c  s3_ch_ae  s3_qg19   s3_qa27   s3_ch_az s2_ch1_f  s2_ch_bc  s3_ch1_f  s3_qf10   s3_ch_af  s3_qg20   s3_qa28   s3_ch_ba s2_ch1_g  s2_ch_bd  s3_ch1_g  s3_qg5_c  s3_ch_ag  s3_qh15   s3_qa29   s3_ch_bb s2_ch1_h  s2_ch_be  s3_ch1_h  s3_qg6_c  s3_q14_g  s3_qh16   s3_qa30   s3_ch_bc s2_ch1_i  s2_ch_bf  s3_ch1_i  s3_qg7_c  s3_q14_h  s3_qh17   s3_qb25   s3_ch_bd s2_ch1_j  s2_ch_bg  s3_ch1_j  s3_qg8_c  s3_q14_i  s3_qh18   s3_qb26   s3_ch_be s2_ch1_k  s2_ch_bh  s3_ch1_k  s3_qg9_c  s3_q14_j  s3_qh19   s3_qb27   s3_ch_bf s2_ch1_l  s2_ch_bi  s3_ch1_l  s3_qg10   s3_q14_k  s3_qh20   s3_qb28   s3_ch_bg s2_ch1_m  s2_ch_bj  s3_ch1_m  s3_qh5_c  s3_q14_l  s3_qi15   s3_qb29   s3_ch_bh s2_ch1_n  s2_ch_bk  s3_ch1_n  s3_qh6_c  s3_qa15   s3_qi16   s3_qb30   s3_ch_bi s2_ch1_o  s2_ch_bl  s3_ch1_o  s3_qh7_c  s3_qa16   s3_qi17   s3_qc25   s3_ch_bj s2_ch1_p  s2_ch_bm  s3_ch1_p  s3_qh8_c  s3_qa17   s3_qi18   s3_qc26   s3_ch_bk s2_ch1_q  s2_ch_bn  s3_ch1_q  s3_qh9_c  s3_qa18   s3_qi19   s3_qc27   s3_ch_bl s2_ch1_r  s2_ch_bo  s3_ch1_r  s3_qh10   s3_qa19   s3_qi20   s3_qc28   s3_ch_bm s2_ch1_s  s2_ch_bp  s3_ch1_s  s3_qi5_c  s3_qa20   s3_qj15   s3_qc29   s3_ch_bn s2_ch1_t  s2_ch_bq  s3_qa5_c  s3_qi6_c  s3_qb15   s3_qj16   s3_qc30   s3_ch_bo s2_ch1_u  s2_ch_br  s3_qa6_c  s3_qi7_c  s3_qb16   s3_qj17   s3_qd25   s3_ch_bp s2_ch1_v  s2_ch_bs  s3_qa7_c  s3_qi8_c  s3_qb17   s3_qj18   s3_qd26   s3_ch_bq s2_ch1_w  s2_ch_bt  s3_qa8_c  s3_qi9_c  s3_qb18   s3_qj19   s3_qd27   s3_ch_br s2_ch1_x  s2_ch_bu  s3_qa9_c  s3_qi10   s3_qb19   s3_qj20   s3_qd28   s3_ch_bs s2_ch1_y  s2_ch_bv  s3_qa10   s3_qj5_c  s3_qb20   s3_qk15   s3_qd29   s3_ch_bt s2_ch1_z  s2_ch_bw  s3_qb5_c  s3_qj6_c  s3_qc15   s3_qk16   s3_qd30   s3_ch_bu s2_ch_aa  s2_ch_bx  s3_qb6_c  s3_qj7_c  s3_qc16   s3_qk17   s3_qe25   s3_ch_bv s2_ch_ab  s2_ch_by  s3_qb7_c  s3_qj8_c  s3_qc17   s3_qk18   s3_qe26   s3_ch_bw s2_ch_ac  s2_ch_bz  s3_qb8_c  s3_qj9_c  s3_qc18   s3_qk19   s3_qe27   s3_ch_bx s2_ch_ad  s2_ch_ca  s3_qb9_c  s3_qj10   s3_qc19   s3_qk20   s3_qe28   s3_ch_by s2_ch_ae  s2_ch_cb  s3_qb10   s3_qk5_c  s3_qc20   s3_ql15   s3_qe29   s4_q1_na s2_ch_af  s2_ch_cc  s3_qc5_c  s3_qk6_c  s3_qd15   s3_ql16   s3_qe30   s4_q1__a s2_ch_ag  s2_ch_cd  s3_qc6_c  s3_qk7_c  s3_qd16   s3_ql17   s3_qf25   s4_q2_ti s2_ch_ah  s2_ch_ce  s3_qc7_c  s3_qk8_c  s3_qd17   s3_ql18   s3_qf26   s4_q3_nu s2_ch_ai  s2_ch_cf  s3_qc8_c  s3_qk9_c  s3_qd18   s3_ql19   s3_qf27   s4_q4a s2_ch_aj  s2_ch_cg  s3_qc9_c  s3_qk10   s3_qd19   s3_ql20   s3_qf28   s4_q4b s2_ch_ak  s2_ch_ch  s3_qc10   s3_ql5_c  s3_qd20   s3_ch_ah  s3_qf29   s4_q5_na s2_ch_al  s2_ch_ci  s3_qd5_c  s3_ql6_c  s3_qe15   s3_ch_ai  s3_qf30   s4_q6 s2_ch_am  s2_ch_cj  s3_qd6_c  s3_ql7_c  s3_qe16   s3_ch_aj  s3_qg25   uid s2_ch_an  s2_ch_ck  s3_qd7_c  s3_ql8_c  s3_qe17   s3_ch_ak  s3_qg26 s2_ch_ao  s2_ch_cl  s3_qd8_c  s3_ql9_c  s3_qe18   s3_ch_al  s3_qg27 s2_ch_ap  s2_ch_cm  s3_qd9_c  s3_ql10   s3_qe19   s3_ch_am  s3_qg28, mv(.z = 0)


**************************************************
***  Identify skip patterns
**************************************************
gen error01 = (s3_ch_ao == 2 & (s3_ch_ap < . | s3_q24_m < . | s3_q24_n < . | s3_q24_o < . | s3_q24_p < . | s3_q24_q < . | s3_q24_r < . |  s3_qa25 < . | s3_qa26 < . | s3_qa27 < . | s3_qa28 < . | s3_qa29 < . | s3_qa30 < . | s3_qb25 < . | s3_qb26 < . | s3_qb27 < . | s3_qb28 < . | s3_qb29 < . | s3_qb30 < . | s3_qc25 < . | s3_qc27 < . | s3_qc26 < . | s3_qc28 < . | s3_qc29 < . | s3_qc30 < . | s3_qd25 < . | s3_qd26 < . | s3_qd27 < . | s3_qd28 < . | s3_qd29 < . | s3_qd30 < . | s3_qe25 < . | s3_qe26 < . | s3_qe27 < . | s3_qe28 ))
gen error02 = (s3_ch_af == 2 & (s3_ch_ag < . | s3_q14_g < . | s3_q14_h < . | s3_q14_i < . | s3_q14_j < . | s3_q14_k < . | s3_q14_l < . | s3_qa15 < . | s3_qa16 < . | s3_qa17 < . | s3_qa18 < . | s3_qa19 < . | s3_qa20 < . | s3_qb15 < . | s3_qb16 < . | s3_qb17  < . |  s3_qb18  < . | s3_qb19  < . | s3_qb20  < . | s3_qc15  < . | s3_qc16  < . | s3_qc17  < . | s3_qc18  < . | s3_qc19  < . | s3_qc20  < . | s3_qd15  < . | s3_qd16  < . | s3_qd17  < . | s3_qd18  < . | s3_qd19  < . | s3_qd20  < . | s3_qe15  < . | s3_qe16  < . | s3_qe17  < . | s3_qe18  < . | s3_qe19  < . | s3_qe20  < . | s3_qf15  < . | s3_qf16  < . | s3_qf17  < . | s3_qf18  < . | s3_qf19  < . | s3_qf20  < . | s3_qg15  < . | s3_qg16  < . | s3_qg17  < . | s3_qg18  < . | s3_qg19  < . | s3_qg20  < . | s3_qh15  < . | s3_qh16  < . | s3_qh17  < . | s3_qh18  < . | s3_qh19  < . | s3_qh20))

**************************************************
*** Identify errors to be reviewed
**************************************************
cd "Source/Cambodia 2004 P E/Data/4.3. Clean Data/4.3.3. Data Code Book"
log using "provincial treasury codebook errors ", replace
codebook error* grubbs*, compact
log close
drop error* grubbs*

